@@ -332,14 +332,14 @@ class API(Record('url', 'http')):
     def _post(self, *args, **kwargs):
         """Shim for issuing POST requests."""
 
-        return self(method="POST")
+        return self(*args, **kwargs.setdefault('method', 'POST'))
 
     def _put(self, *args, **kwargs):
         """Shim for issuing PUT requests."""
 
-        return self(method="PUT")
+        return self(*args, **kwargs.setdefault('method', 'PUT'))
 
     def _delete(self, *args, **kwargs):
         """Shim for issuing DELETE requests."""
 
-        return self(method="DELETE")
+        return self(*args, **kwargs.setdefault('method', 'DELETE'))
