@@ -10,7 +10,7 @@ At the moment this just contains the default HTTP backend for
 from requests import request
 
 from intessa.conneg.default import DEFAULT_REGISTER
-from intessa.response import Response
+from intessa.response import Response, ResponseException
 
 
 def requests_http_backend(api, method, url, *args, **kwargs):
@@ -18,12 +18,15 @@ def requests_http_backend(api, method, url, *args, **kwargs):
 
     codec_register = kwargs.pop('codec_register', DEFAULT_REGISTER)
     http_response = request(method, url, *args, **kwargs)
-    # This will only raise URLErrors related to connection issues, not HTTP
-    # error codes.
-    if http_response.error:
+
+    response = Response(api=api,
+                        status_code=http_response.status_code,
+                        headers=http_response.headers,
+                        content=http_response.content,
+                        codec_register=codec_register)
+
+    if response.status_code // 100 != 2:
+        raise ResponseException(response)
+    elif http_response.error:
         raise http_response.error
-    return Response(api=api,
-                    status_code=http_response.status_code,
-                    headers=http_response.headers,
-                    content=http_response.content,
-                    codec_register=codec_register)
+    return response
